@@ -1,3 +1,5 @@
+//! core module
+
 pub mod types;
 pub mod enc;
 pub mod dec;
@@ -19,17 +21,17 @@ pub(crate) mod major {
 
 pub(crate) mod marker {
     pub const START: u8 = 0x1f;
-    pub const FALSE: u8 = 0xf4;
-    pub const TRUE: u8  = 0xf5;
-    pub const NULL: u8  = 0xf6;
-    pub const UNDEFINED: u8 = 0xf7;
+    pub const FALSE: u8 = 0xf4; // simple(20)
+    pub const TRUE: u8  = 0xf5; // simple(21)
+    pub const NULL: u8  = 0xf6; // simple(22)
+    pub const UNDEFINED: u8 = 0xf7; // simple(23)
     pub const F16: u8   = 0xf9;
     pub const F32: u8   = 0xfa;
     pub const F64: u8   = 0xfb;
     pub const BREAK: u8   = 0xff;
 }
 
-#[cfg_attr(feature = "serde-value", derive(serde::Serialize, serde::Deserialize))]
+#[cfg_attr(feature = "serde1-value", derive(serde::Serialize, serde::Deserialize))]
 #[cfg(feature = "use_alloc")]
 #[derive(Debug, PartialEq)]
 #[non_exhaustive]
@@ -68,11 +70,11 @@ impl<'de> dec::Decode<'de> for Value {
         use crate::util::ScopeGuard;
 
         if !reader.step_in() {
-            return Err(dec::Error::RecursionLimit);
+            return Err(dec::Error::DepthLimit);
         }
 
         let mut reader = ScopeGuard(reader, |reader| reader.step_out());
-        let reader = reader.get_mut();
+        let reader = &mut *reader;
 
         match byte >> 5 {
             major::UNSIGNED => u64::decode_with(byte, reader)
