@@ -543,7 +543,6 @@ impl<'a> Decode<'a> for types::BadStr<alloc::borrow::Cow<'a, [u8]>> {
         } else {
             Cow::Owned(buf)
         }))
-
     }
 }
 
@@ -560,6 +559,15 @@ pub(crate) fn decode_len<'a, R: Read<'a>>(major: u8, byte: u8, reader: &mut R)
     }
 }
 
+pub struct ArrayStart(pub Option<usize>);
+
+impl<'a> Decode<'a> for ArrayStart {
+    #[inline]
+    fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
+        decode_len(major::ARRAY, byte, reader).map(ArrayStart)
+    }
+}
+
 #[cfg(feature = "use_alloc")]
 impl<'a, T: Decode<'a>> Decode<'a> for Vec<T> {
     #[inline]
@@ -598,6 +606,15 @@ impl<'a, T: Decode<'a>> Decode<'a> for Vec<T> {
     }
 }
 
+pub struct MapStart(pub Option<usize>);
+
+impl<'a> Decode<'a> for MapStart {
+    #[inline]
+    fn decode_with<R: Read<'a>>(byte: u8, reader: &mut R) -> Result<Self, Error<R::Error>> {
+        decode_len(major::MAP, byte, reader).map(MapStart)
+    }
+}
+
 #[cfg(feature = "use_alloc")]
 impl<'a, K: Decode<'a>, V: Decode<'a>> Decode<'a> for types::Map<Vec<(K, V)>> {
     #[inline]
@@ -736,3 +753,13 @@ impl<'a> Decode<'a> for f64 {
         }
     }
 }
+
+#[inline]
+pub fn is_break<'a, R: Read<'a>>(reader: &mut R) -> Result<bool, Error<R::Error>> {
+    if peek_one(reader)? == marker::BREAK {
+        reader.advance(1);
+        Ok(true)
+    } else {
+        Ok(false)
+    }
+}
